server

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 12, 2025 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Config

type Config struct {

	// Addr is the address the server should listen on.
	Addr string

	// Logger can be used to capture log messages.
	Logger *slog.Logger

	// Storage is a pointer to a Storage instance
	Storage *storage.Storage
}

Config provides configuration for Server.

type Server

type Server struct {
	// contains filtered or unexported fields
}

Server provides the web interface for interacting with the CA and certificate functions in the storage package.

func New

func New(cfg *Config) (*Server, error)

New create a new Server instance.

func (*Server) Close

func (s *Server) Close()

Close shuts down the server.

Jump to